@@ -179,14 +179,14 @@ class StationBTechnogenetics(StationB):
         self.remove_supernatant(self._starting_vol)
         self.wash(self._wash_1_vol, self.wash1, self._wash_1_times, "wash A")
 
-        if self.run_stage("spin deepwell"):
+        if self.run_stage("spin deepwell wash A"):
             self._magdeck.disengage()
             self.dual_pause("spin the deepwell", between=self.set_external)
             self.set_internal()
             self._magdeck.engage(height=self._magheight)
             self.check()
 
-        if self.run_stage("post spin incubation"):
+        if self.run_stage("post spin incubation wash A"):
             self.delay(self._postspin_incubation_time, self.get_msg_format("incubate on magdeck", self.get_msg("on")))
 
         self.remove_wash(self._remove_wash_vol, "remove wash A after spin")
@@ -196,14 +196,14 @@ class StationBTechnogenetics(StationB):
 
         self.wash(self._wash_2_vol, self.wash2, self._wash_2_times, "wash B")
         
-        if self.run_stage("spin deepwell"):
+        if self.run_stage("spin deepwell wash B"):
             self._magdeck.disengage()
             self.dual_pause("spin the deepwell", between=self.set_external)
             self.set_internal()
             self._magdeck.engage(height=self._magheight)
             self.check()
         
-        if self.run_stage("post spin incubation"):
+        if self.run_stage("post spin incubation wash B"):
             self.delay(self._postspin_incubation_time, self.get_msg_format("incubate on magdeck", self.get_msg("on")))
         
         self.remove_wash(self._remove_wash_vol, "remove wash B after spin")
